@@ -1,7 +1,7 @@
 """
 Type annotations for outposts service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_outposts/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AddressTypeType,
     CatalogItemClassType,
@@ -480,6 +482,9 @@ ListSitesInputRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
+        "OperatingAddressCountryCodeFilter": Sequence[str],
+        "OperatingAddressStateOrRegionFilter": Sequence[str],
+        "OperatingAddressCityFilter": Sequence[str],
     },
     total=False,
 )
